@@ -73,7 +73,7 @@ sub _build_selenium ($self) {
         # NOTE on linux don't forget to install dependencies: yum install Xvfb xorg-x11-fonts*
         $self->_appx_report_info( q[Downloading: selenium-server-standalone-] . $self->selenium_ver . q[.jar] );
 
-        P->http->mirror( $self->alien_bin_path, $self->selenium_uri, blocking => 1, on_progress => 1 );
+        my $res = P->http->mirror( $self->alien_bin_path, $self->selenium_uri, on_progress => 1 );
 
         $self->_appx_report_fatal(q[Selenium deployment error]) if !-e $self->alien_bin_path;
     }
@@ -94,15 +94,15 @@ sub _build_ff ($self) {
 
         $self->_appx_report_info( q[Downloading: ] . $uri );
 
-        P->http->mirror( $store_to, $uri, blocking => 1, on_progress => 1 );
+        my $res = P->http->mirror( $store_to, $uri, on_progress => 1 );
 
         P->file->mkpath( $self->ff_dir );
 
         if ($MSWIN) {
-            P->pm->run_capture(qq[winrar x -o+ -apcore -df -ibck "$store_to" core "@{[$self->ff_dir]}"]);
+            P->pm->run_proc( qq[winrar x -o+ -apcore -df -ibck "$store_to" core "@{[$self->ff_dir]}"], stdout => 1, stderr => 2 ) or die;
         }
         else {
-            P->pm->run_capture(qq[tar --overwrite --strip-components=1 -xvf "$store_to" -C "@{[$self->ff_dir]}"]);
+            P->pm->run_proc( qq[tar --overwrite --strip-components=1 -xvf "$store_to" -C "@{[$self->ff_dir]}"], stdout => 1, stderr => 2 ) or die;
         }
 
         if ( !-e $self->ff_bin_path ) {
@@ -125,11 +125,12 @@ sub _build_ff_extensions ($self) {
     for my $ext ( sort keys $self->cfg->{SELENIUM}->{FF_EXTENSIONS}->%* ) {
         $self->_appx_report_info(qq[Downloading: $ext]);
 
+        $cv->begin;
+
         P->http->get(
             $self->cfg->{SELENIUM}->{FF_EXTENSIONS}->{$ext},
             buf_size    => 1,
             on_progress => 1,
-            cv          => $cv,
             on_finish   => sub ($res) {
                 if ( $res->status == 200 ) {
                     my $zip = Archive::Zip->new;
@@ -144,6 +145,8 @@ sub _build_ff_extensions ($self) {
                     die qq[Error downloading FF extension];
                 }
 
+                $cv->end;
+
                 return;
             }
         );
@@ -208,7 +211,7 @@ sub master_proc ($self) {
 
 sub alien_proc ($self) {
     if ($MSWIN) {
-        P->pm->run_check( $self->_cmd );
+        P->pm->run_proc( $self->_cmd ) or die;
 
         exit 0;
     }
@@ -228,7 +231,7 @@ sub alien_proc ($self) {
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
 ## │    3 │ 125                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 144                  │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
+## │    3 │ 145                  │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
