@@ -51,7 +51,7 @@ sub _parse_find_element_params {
 
 sub find_element {
     my $self = shift;
-    P->log->debug( 'find element: ' . join ', ', @_ );
+    P->log->sendlog( 'Pcore-Selenium', 'find element: ' . join ', ', @_ );
     my $params = $self->_parse_find_element_params( \@_ );
     my $res    = try {
         return __find_element( $self, @{ $params->{driver} } );
@@ -69,7 +69,7 @@ sub find_element {
 sub find_elements {
     my $self = shift;
 
-    P->log->debug( 'find elements: ' . join ', ', @_ );
+    P->log->sendlog( 'Pcore-Selenium', 'find elements: ' . join ', ', @_ );
 
     my $params = $self->_parse_find_element_params( \@_ );
 
@@ -95,7 +95,7 @@ sub find_child_element {
     my $self   = shift;
     my $parent = shift;
 
-    P->log->debug( 'find child element: ' . join ', ', @_ );
+    P->log->sendlog( 'Pcore-Selenium', 'find child element: ' . join ', ', @_ );
 
     my $params = $self->_parse_find_element_params( \@_ );
 
@@ -119,7 +119,7 @@ sub find_child_elements {
     my $self   = shift;
     my $parent = shift;
 
-    P->log->debug( 'find child elements: ' . join ', ', @_ );
+    P->log->sendlog( 'Pcore-Selenium', 'find child elements: ' . join ', ', @_ );
 
     my $params = $self->_parse_find_element_params( \@_ );
 
